# HTTP Echo

## Description

This skill echos the HTTP requests it receives as HTTP response.

This skill is part of the Fetch.ai "HTTP Connection and Skill" guide. Upon receiving an HTTP request, it sends back the same information in the request as an HTTP response.

## Behaviours 

## Handlers

* http_handler: handles http messages for echoing back an HTTP request as an HTTP response.

## Links

* <a href="https://docs.fetch.ai/aea/http-connection-and-skill/" target="_blank">HTTP Connection and Skill</a>